package com.antai.sport.http.server.management.api.business.simplematch.service;

import com.antai.sport.http.server.common.exception.BusinessException;
import com.antai.sport.http.server.constants.DeleteStatus;
import com.antai.sport.http.server.management.api.business.simplematch.dto.SimpleMatchListRequestDTO;
import com.antai.sport.http.server.management.api.business.simplematch.dto.SimpleMatchListResponseDTO;
import com.antai.sport.http.server.management.api.business.simplematch.dto.vo.SimpleMatchListVO;
import com.antai.sport.http.server.management.api.business.simplematch.mapper.SimpleMatchBusinessMapper;
import com.antai.sport.http.server.repository.simplematch.entity.SimpleMatch;
import com.antai.sport.http.server.repository.simplematch.mapper.SimpleMatchMapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.metadata.OrderItem;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;

@Service
public class SimpleMatchService {
    @Resource
    private SimpleMatchMapper simpleMatchMapper;
    @Resource
    private SimpleMatchBusinessMapper simpleMatchBusinessMapper;

    public SimpleMatchListResponseDTO getMatchList(SimpleMatchListRequestDTO param) {
        Page<SimpleMatchListVO> pageParam = new Page<>(param.getPageNo(), param.getPageSize());
        if (StringUtils.isNotEmpty(param.getSortOrder())) {
            pageParam.addOrder(new OrderItem("start_time", "asc".equals(param.getSortOrder())));
        }
        pageParam.addOrder(new OrderItem("id", false));
        IPage<SimpleMatchListVO> result = simpleMatchBusinessMapper.getMatchList(pageParam, param);

        SimpleMatchListResponseDTO dto = new SimpleMatchListResponseDTO();
        dto.setData(result.getRecords());
        dto.setPageNo(param.getPageNo());
        dto.setTotalCount(result.getTotal());
        return dto;
    }

    public void deleteMatch(Long matchId) {
        SimpleMatch simpleMatch = simpleMatchMapper.selectById(matchId);
        if (simpleMatch.getStatus() != null && simpleMatch.getStatus().equals(20)) {
            throw new BusinessException("已发布比赛不能删除");
        }
        simpleMatch.setDeleted(Integer.valueOf(DeleteStatus.DELETED));
        simpleMatchMapper.updateById(simpleMatch);
    }

    public void publish(Long matchId) {
        SimpleMatch simpleMatch = simpleMatchMapper.selectById(matchId);
        if (simpleMatch.getStatus() == null || simpleMatch.getStatus().equals(10)) {
            simpleMatch.setStatus(20);
        } else {
            simpleMatch.setStatus(10);
        }
        simpleMatchMapper.updateById(simpleMatch);
    }

}
